@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::CommitBuild;
 {
-  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '1.121810';
+  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '1.121811';
 }
 # ABSTRACT: checkin build results on separate branch
 
@@ -151,7 +151,7 @@ sub _create_tree {
 
     ### @entries
 
-    my ($sha) = $repo->mktree({ -STDIN => join('\n', @entries, q{}) });
+    my ($sha) = $repo->mktree({ -STDIN => join("\n", @entries, q{}) });
 
     return $sha;
 }
@@ -167,7 +167,7 @@ Dist::Zilla::Plugin::Git::CommitBuild - checkin build results on separate branch
 
 =head1 VERSION
 
-version 1.121810
+version 1.121811
 
 =head1 SYNOPSIS
 
